/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2013 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp13nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp13nid ;

DATA library.&dataset ;
INFILE datafile LRECL=2308;
INPUT
   DISGORGE  1-6            ACCEPT  7-8              BOOKER2  9            
   BOOKER3  10              BOOKERCD  11-12          BUSCLAS  13-16        
   CANTPAY  17              CCULPSCO  18             CH2APP  19            
   CH8FINGD  20             CMSRVORD  21             COFI  22              
   COMPLY  23-24            COMPLYPR  25             CRIMPURP  26          
   DETBFINE  27             DISPOSIT  28             EMPLOYNM  29          
   FCULPSCO  30             FRAUDTYP  31-32          FINSTDS  33           
   HISTORY  34              HSMISCND  35             INCORLOC  36          
   INCORPYR  37-40          INDICT  41               INPLEA1  42           
   INPLEA2  43              INPLEA3  44              INPLEA4  45           
   INPLEA5  46              INPLEA6  47              INPLEA7  48           
   INPLEA8  49              INPLEA9  50              INPLEA10  51          
   INPLEA11  52             INPLEA12  53             INNOPL1  54           
   INNOPL2  55              INNOPL3  56              INNOPL4  57           
   INNOPL5  58              INNOPL6  59              INNOPL7  60           
   INNOPL8  61              INNOPL9  62              INNOPL10  63          
   INNOPL11  64             INNOPL12  65             JANDC  66             
   NEWCNVTN  67             NOCOMP  68               NOCOUNTS  69-70       
   NOUSTAT  71              OBSTRUCT  72             OFFLVL  73-74         
   ORDERCE  75              ORGTYPE  76              OWNSTRCT  77-78       
   PLEA  79                 PRIMOFF  80-81           PRCIVIL  82           
   PRCRIME  83              PROBATN  84-85           PROBMON  86           
   PSR  87                  QUARTER  88              REAS1  89-92          
   REAS2  93                REAS3  94                REAS4  95             
   REAS5  96                REAS6  97                REAS7  98             
   REAS8  99                REAS9  100               REAS10  101           
   REASONS  102             REMEDORD  103            SELFREP  104          
   SOURCES  105             TOLERNCE  106            TYPEOTHS  107-108     
   VICTNOTE  109            VIOLATE  110             AMENDYR  111-114      
   SENTYR  115-118          BASEFINE  119-126        COSTASSM  127         
   FINOFFST  128-133        FORFEITR  134-141        GLFINMAX  142-150     
   GLFINMIN  151-158        STATMIN  159-162         STATMAX  163-171      
   CPIDN  172-178           BUSTEXT $ 179-244        OWNSTEXT $ 245-250    
   FINSTXT $ 251-283        PRMONTXT $ 284-370       TYPEOTTX $ 371-570    
   ORDERTXT $ 571-670       MINFINML  671-674        MAXFINML  675-677     
   ADJOFL1  678-679         ADJOFL2  680-681         ADJOFLHI  682-683     
   ADJ_B1  684-685          ADJ_B2  686              ADJ_BHI  687-688      
   ADJ_C1  689-690          ADJ_C2  691              ADJ_CHI  692-693      
   ADJ_D1  694-696          ADJ_D2  697              ADJ_DHI  698-700      
   ADJ_E1  701              ADJ_E2  702              ADJ_EHI  703          
   ADJ_F1  704              ADJ_F2  705              ADJ_FHI  706          
   ADJ_G1  707              ADJ_G2  708              ADJ_GHI  709          
   ADJ_H1  710              ADJ_H2  711              ADJ_HHI  712          
   ADJ_I1  713              ADJ_I2  714              ADJ_IHI  715          
   ADJ_J1  716              ADJ_J2  717              ADJ_JHI  718          
   ADJ_K1  719              ADJ_K2  720              ADJ_KHI  721          
   ADJ_L1  722              ADJ_L2  723              ADJ_LHI  724          
   ADJ_M1  725              ADJ_M2  726              ADJ_MHI  727          
   ADJ_N1  728              ADJ_N2  729              ADJ_NHI  730          
   ADJ_O1  731              ADJ_O2  732              ADJ_OHI  733          
   ADJ_P1  734              ADJ_P2  735              ADJ_PHI  736          
   ADJ_Q1  737              ADJ_Q2  738              ADJ_QHI  739          
   ADJ_R1  740              ADJ_R2  741              ADJ_RHI  742          
   ADJ_S1  743              ADJ_S2  744              ADJ_SHI  745          
   BASADJ1  746-747         BASADJ2  748             BASADJHI  749-750     
   BASE1  751-752           BASE2  753-754           BASEHI  755-756       
   BASLN1  757              BASLN2  758              BASLNHI  759          
   ADJOFR1  760-761         ADJOFR2  762             ADJOFRHI  763-764     
   ADJR_B1  765-766         ADJR_B2  767             ADJR_BHI  768-769     
   ADJR_C1  770             ADJR_C2  771             ADJR_CHI  772         
   ADJR_D1  773             ADJR_D2  774             ADJR_DHI  775         
   ADJR_E1  776             ADJR_E2  777             ADJR_EHI  778         
   ADJR_F1  779             ADJR_F2  780             ADJR_FHI  781         
   ADJR_G1  782             ADJR_G2  783             ADJR_GHI  784         
   ADJR_H1  785             ADJR_H2  786             ADJR_HHI  787         
   ADJR_I1  788             ADJR_I2  789             ADJR_IHI  790         
   ADJR_J1  791             ADJR_J2  792             ADJR_JHI  793         
   ADJR_K1  794             ADJR_K2  795             ADJR_KHI  796         
   ADJR_L1  797             ADJR_L2  798             ADJR_LHI  799         
   ADJR_M1  800             ADJR_M2  801             ADJR_MHI  802         
   ADJR_N1  803             ADJR_N2  804             ADJR_NHI  805         
   ADJR_O1  806             ADJR_O2  807             ADJR_OHI  808         
   ADJR_P1  809             ADJR_P2  810             ADJR_PHI  811         
   ADJR_Q1  812             ADJR_Q2  813             ADJR_QHI  814         
   ADJR_R1  815             ADJR_R2  816             ADJR_RHI  817         
   ADJR_S1  818             ADJR_S2  819             ADJR_SHI  820         
   BASADR1  821             BASADR2  822             BASADRHI  823         
   BASER1  824-825          BASER2  826              BASERHI  827-828      
   BASLNR1  829             BASLNR2  830             BASLNRHI  831         
   ADJOFS1  832-833         ADJOFS2  834-835         ADJOFSHI  836-837     
   ADJS_B1  838-839         ADJS_B2  840             ADJS_BHI  841-842     
   ADJS_C1  843-844         ADJS_C2  845             ADJS_CHI  846-847     
   ADJS_D1  848-850         ADJS_D2  851             ADJS_DHI  852-854     
   ADJS_E1  855             ADJS_E2  856             ADJS_EHI  857         
   ADJS_F1  858             ADJS_F2  859             ADJS_FHI  860         
   ADJS_G1  861             ADJS_G2  862             ADJS_GHI  863         
   ADJS_H1  864             ADJS_H2  865             ADJS_HHI  866         
   ADJS_I1  867             ADJS_I2  868             ADJS_IHI  869         
   ADJS_J1  870             ADJS_J2  871             ADJS_JHI  872         
   ADJS_K1  873             ADJS_K2  874             ADJS_KHI  875         
   ADJS_L1  876             ADJS_L2  877             ADJS_LHI  878         
   ADJS_M1  879             ADJS_M2  880             ADJS_MHI  881         
   ADJS_N1  882             ADJS_N2  883             ADJS_NHI  884         
   ADJS_O1  885             ADJS_O2  886             ADJS_OHI  887         
   ADJS_P1  888             ADJS_P2  889             ADJS_PHI  890         
   ADJS_Q1  891             ADJS_Q2  892             ADJS_QHI  893         
   ADJS_R1  894             ADJS_R2  895             ADJS_RHI  896         
   ADJS_S1  897             ADJS_S2  898             ADJS_SHI  899         
   BASADS1  900-901         BASADS2  902             BASADSHI  903-904     
   BASES1  905-906          BASES2  907-908          BASESHI  909-910      
   BASLNS1  911             BASLNS2  912             BASLNSHI  913         
   ADJOFC1  914-915         ADJOFC2  916             ADJOFCHI  917-918     
   ADJC_B1  919-920         ADJC_B2  921             ADJC_BHI  922-923     
   ADJC_C1  924             ADJC_C2  925             ADJC_CHI  926         
   ADJC_D1  927             ADJC_D2  928             ADJC_DHI  929         
   ADJC_E1  930             ADJC_E2  931             ADJC_EHI  932         
   ADJC_F1  933             ADJC_F2  934             ADJC_FHI  935         
   ADJC_G1  936             ADJC_G2  937             ADJC_GHI  938         
   ADJC_H1  939             ADJC_H2  940             ADJC_HHI  941         
   ADJC_I1  942             ADJC_I2  943             ADJC_IHI  944         
   ADJC_J1  945             ADJC_J2  946             ADJC_JHI  947         
   ADJC_K1  948             ADJC_K2  949             ADJC_KHI  950         
   ADJC_L1  951             ADJC_L2  952             ADJC_LHI  953         
   ADJC_M1  954             ADJC_M2  955             ADJC_MHI  956         
   ADJC_N1  957             ADJC_N2  958             ADJC_NHI  959         
   ADJC_O1  960             ADJC_O2  961             ADJC_OHI  962         
   ADJC_P1  963             ADJC_P2  964             ADJC_PHI  965         
   ADJC_Q1  966             ADJC_Q2  967             ADJC_QHI  968         
   ADJC_R1  969             ADJC_R2  970             ADJC_RHI  971         
   ADJC_S1  972             ADJC_S2  973             ADJC_SHI  974         
   BASADC1  975             BASADC2  976             BASADCHI  977         
   BASEC1  978              BASEC2  979              BASECHI  980          
   BASLNC1  981             BASLNC2  982             BASLNCHI  983         
   ADJOFU1  984             ADJOFU2  985             ADJOFUHI  986         
   ADJU_B1  987             ADJU_B2  988             ADJU_BHI  989         
   ADJU_C1  990             ADJU_C2  991             ADJU_CHI  992         
   ADJU_D1  993             ADJU_D2  994             ADJU_DHI  995         
   ADJU_E1  996             ADJU_E2  997             ADJU_EHI  998         
   ADJU_F1  999             ADJU_F2  1000            ADJU_FHI  1001        
   ADJU_G1  1002            ADJU_G2  1003            ADJU_GHI  1004        
   ADJU_H1  1005            ADJU_H2  1006            ADJU_HHI  1007        
   ADJU_I1  1008            ADJU_I2  1009            ADJU_IHI  1010        
   ADJU_J1  1011            ADJU_J2  1012            ADJU_JHI  1013        
   ADJU_K1  1014            ADJU_K2  1015            ADJU_KHI  1016        
   ADJU_L1  1017            ADJU_L2  1018            ADJU_LHI  1019        
   ADJU_M1  1020            ADJU_M2  1021            ADJU_MHI  1022        
   ADJU_N1  1023            ADJU_N2  1024            ADJU_NHI  1025        
   ADJU_O1  1026            ADJU_O2  1027            ADJU_OHI  1028        
   ADJU_P1  1029            ADJU_P2  1030            ADJU_PHI  1031        
   ADJU_Q1  1032            ADJU_Q2  1033            ADJU_QHI  1034        
   ADJU_R1  1035            ADJU_R2  1036            ADJU_RHI  1037        
   ADJU_S1  1038            ADJU_S2  1039            ADJU_SHI  1040        
   BASADU1  1041            BASADU2  1042            BASADUHI  1043        
   BASEU1  1044             BASEU2  1045             BASEUHI  1046         
   BASLNU1  1047            BASLNU2  1048            BASLNUHI  1049        
   ADJL_B1 $ 1050           ADJL_B2 $ 1051           ADJL_BHI $ 1052       
   ADJL_C1 $ 1053-1054      ADJL_C2 $ 1055           ADJL_CHI $ 1056-1057  
   ADJL_D1 $ 1058           ADJL_D2 $ 1059           ADJL_DHI $ 1060       
   ADJL_E1 $ 1061           ADJL_E2 $ 1062           ADJL_EHI $ 1063       
   ADJL_F1 $ 1064           ADJL_F2 $ 1065           ADJL_FHI $ 1066       
   ADJL_G1 $ 1067           ADJL_G2 $ 1068           ADJL_GHI $ 1069       
   ADJL_H1 $ 1070           ADJL_H2 $ 1071           ADJL_HHI $ 1072       
   ADJL_I1 $ 1073-1074      ADJL_I2 $ 1075           ADJL_IHI $ 1076-1077  
   ADJL_J1 $ 1078           ADJL_J2 $ 1079           ADJL_JHI $ 1080       
   ADJL_K1 $ 1081           ADJL_K2 $ 1082           ADJL_KHI $ 1083       
   ADJL_L1 $ 1084-1085      ADJL_L2 $ 1086           ADJL_LHI $ 1087-1088  
   ADJL_M1 $ 1089           ADJL_M2 $ 1090           ADJL_MHI $ 1091       
   ADJL_N1 $ 1092           ADJL_N2 $ 1093           ADJL_NHI $ 1094       
   ADJL_O1 $ 1095           ADJL_O2 $ 1096           ADJL_OHI $ 1097       
   ADJL_P1 $ 1098           ADJL_P2 $ 1099           ADJL_PHI $ 1100       
   ADJL_Q1 $ 1101           ADJL_Q2 $ 1102           ADJL_QHI $ 1103       
   ADJL_R1 $ 1104-1105      ADJL_R2 $ 1106           ADJL_RHI $ 1107-1108  
   ADJL_S1 $ 1109           ADJL_S2 $ 1110           ADJL_SHI $ 1111       
   BASEL1 $ 1112            BASEL2 $ 1113            BASELHI $ 1114        
   ADRL_B1 $ 1115           ADRL_B2 $ 1116           ADRL_BHI $ 1117       
   ADRL_C1 $ 1118           ADRL_C2 $ 1119           ADRL_CHI $ 1120       
   ADRL_D1 $ 1121           ADRL_D2 $ 1122           ADRL_DHI $ 1123       
   ADRL_E1 $ 1124           ADRL_E2 $ 1125           ADRL_EHI $ 1126       
   ADRL_F1 $ 1127           ADRL_F2 $ 1128           ADRL_FHI $ 1129       
   ADRL_G1 $ 1130           ADRL_G2 $ 1131           ADRL_GHI $ 1132       
   ADRL_H1 $ 1133           ADRL_H2 $ 1134           ADRL_HHI $ 1135       
   ADRL_I1 $ 1136           ADRL_I2 $ 1137           ADRL_IHI $ 1138       
   ADRL_J1 $ 1139           ADRL_J2 $ 1140           ADRL_JHI $ 1141       
   ADRL_K1 $ 1142           ADRL_K2 $ 1143           ADRL_KHI $ 1144       
   ADRL_L1 $ 1145           ADRL_L2 $ 1146           ADRL_LHI $ 1147       
   ADRL_M1 $ 1148           ADRL_M2 $ 1149           ADRL_MHI $ 1150       
   ADRL_N1 $ 1151           ADRL_N2 $ 1152           ADRL_NHI $ 1153       
   ADRL_O1 $ 1154           ADRL_O2 $ 1155           ADRL_OHI $ 1156       
   ADRL_P1 $ 1157           ADRL_P2 $ 1158           ADRL_PHI $ 1159       
   ADRL_Q1 $ 1160           ADRL_Q2 $ 1161           ADRL_QHI $ 1162       
   ADRL_R1 $ 1163           ADRL_R2 $ 1164           ADRL_RHI $ 1165       
   ADRL_S1 $ 1166           ADRL_S2 $ 1167           ADRL_SHI $ 1168       
   BASERL1 $ 1169           BASERL2 $ 1170           BASERLHI $ 1171       
   ADSL_B1 $ 1172           ADSL_B2 $ 1173           ADSL_BHI $ 1174       
   ADSL_C1 $ 1175-1176      ADSL_C2 $ 1177           ADSL_CHI $ 1178-1179  
   ADSL_D1 $ 1180           ADSL_D2 $ 1181           ADSL_DHI $ 1182       
   ADSL_E1 $ 1183           ADSL_E2 $ 1184           ADSL_EHI $ 1185       
   ADSL_F1 $ 1186           ADSL_F2 $ 1187           ADSL_FHI $ 1188       
   ADSL_G1 $ 1189           ADSL_G2 $ 1190           ADSL_GHI $ 1191       
   ADSL_H1 $ 1192           ADSL_H2 $ 1193           ADSL_HHI $ 1194       
   ADSL_I1 $ 1195-1196      ADSL_I2 $ 1197           ADSL_IHI $ 1198-1199  
   ADSL_J1 $ 1200           ADSL_J2 $ 1201           ADSL_JHI $ 1202       
   ADSL_K1 $ 1203           ADSL_K2 $ 1204           ADSL_KHI $ 1205       
   ADSL_L1 $ 1206-1207      ADSL_L2 $ 1208           ADSL_LHI $ 1209-1210  
   ADSL_M1 $ 1211           ADSL_M2 $ 1212           ADSL_MHI $ 1213       
   ADSL_N1 $ 1214           ADSL_N2 $ 1215           ADSL_NHI $ 1216       
   ADSL_O1 $ 1217           ADSL_O2 $ 1218           ADSL_OHI $ 1219       
   ADSL_P1 $ 1220           ADSL_P2 $ 1221           ADSL_PHI $ 1222       
   ADSL_Q1 $ 1223           ADSL_Q2 $ 1224           ADSL_QHI $ 1225       
   ADSL_R1 $ 1226-1227      ADSL_R2 $ 1228           ADSL_RHI $ 1229-1230  
   ADSL_S1 $ 1231           ADSL_S2 $ 1232           ADSL_SHI $ 1233       
   BASESL1 $ 1234           BASESL2 $ 1235           BASESLHI $ 1236       
   ADCL_B1 $ 1237           ADCL_B2 $ 1238           ADCL_BHI $ 1239       
   ADCL_C1 $ 1240           ADCL_C2 $ 1241           ADCL_CHI $ 1242       
   ADCL_D1 $ 1243           ADCL_D2 $ 1244           ADCL_DHI $ 1245       
   ADCL_E1 $ 1246           ADCL_E2 $ 1247           ADCL_EHI $ 1248       
   ADCL_F1 $ 1249           ADCL_F2 $ 1250           ADCL_FHI $ 1251       
   ADCL_G1 $ 1252           ADCL_G2 $ 1253           ADCL_GHI $ 1254       
   ADCL_H1 $ 1255           ADCL_H2 $ 1256           ADCL_HHI $ 1257       
   ADCL_I1 $ 1258           ADCL_I2 $ 1259           ADCL_IHI $ 1260       
   ADCL_J1 $ 1261           ADCL_J2 $ 1262           ADCL_JHI $ 1263       
   ADCL_K1 $ 1264           ADCL_K2 $ 1265           ADCL_KHI $ 1266       
   ADCL_L1 $ 1267           ADCL_L2 $ 1268           ADCL_LHI $ 1269       
   ADCL_M1 $ 1270           ADCL_M2 $ 1271           ADCL_MHI $ 1272       
   ADCL_N1 $ 1273           ADCL_N2 $ 1274           ADCL_NHI $ 1275       
   ADCL_O1 $ 1276           ADCL_O2 $ 1277           ADCL_OHI $ 1278       
   ADCL_P1 $ 1279           ADCL_P2 $ 1280           ADCL_PHI $ 1281       
   ADCL_Q1 $ 1282           ADCL_Q2 $ 1283           ADCL_QHI $ 1284       
   ADCL_R1 $ 1285           ADCL_R2 $ 1286           ADCL_RHI $ 1287       
   ADCL_S1 $ 1288           ADCL_S2 $ 1289           ADCL_SHI $ 1290       
   BASECL1 $ 1291           BASECL2 $ 1292           BASECLHI $ 1293       
   ADUL_B1 $ 1294           ADUL_B2 $ 1295           ADUL_BHI $ 1296       
   ADUL_C1 $ 1297           ADUL_C2 $ 1298           ADUL_CHI $ 1299       
   ADUL_D1 $ 1300           ADUL_D2 $ 1301           ADUL_DHI $ 1302       
   ADUL_E1 $ 1303           ADUL_E2 $ 1304           ADUL_EHI $ 1305       
   ADUL_F1 $ 1306           ADUL_F2 $ 1307           ADUL_FHI $ 1308       
   ADUL_G1 $ 1309           ADUL_G2 $ 1310           ADUL_GHI $ 1311       
   ADUL_H1 $ 1312           ADUL_H2 $ 1313           ADUL_HHI $ 1314       
   ADUL_I1 $ 1315           ADUL_I2 $ 1316           ADUL_IHI $ 1317       
   ADUL_J1 $ 1318           ADUL_J2 $ 1319           ADUL_JHI $ 1320       
   ADUL_K1 $ 1321           ADUL_K2 $ 1322           ADUL_KHI $ 1323       
   ADUL_L1 $ 1324           ADUL_L2 $ 1325           ADUL_LHI $ 1326       
   ADUL_M1 $ 1327           ADUL_M2 $ 1328           ADUL_MHI $ 1329       
   ADUL_N1 $ 1330           ADUL_N2 $ 1331           ADUL_NHI $ 1332       
   ADUL_O1 $ 1333           ADUL_O2 $ 1334           ADUL_OHI $ 1335       
   ADUL_P1 $ 1336           ADUL_P2 $ 1337           ADUL_PHI $ 1338       
   ADUL_Q1 $ 1339           ADUL_Q2 $ 1340           ADUL_QHI $ 1341       
   ADUL_R1 $ 1342           ADUL_R2 $ 1343           ADUL_RHI $ 1344       
   ADUL_S1 $ 1345           ADUL_S2 $ 1346           ADUL_SHI $ 1347       
   BASEUL1 $ 1348           BASEUL2 $ 1349           BASEULHI $ 1350       
   GDLINE1 $ 1351-1355      GDLINE2 $ 1356-1360      GDSTAT1 $ 1361-1365   
   GDSTAT2 $ 1366-1370      GDREF1 $ 1371-1375       GDREF2 $ 1376         
   GDCROS1 $ 1377-1381      GDCROS2 $ 1382           GDUNDR1 $ 1383        
   GDUNDR2 $ 1384           GDLINEHI $ 1385-1389     GDSTATHI $ 1390-1394  
   GDREFHI $ 1395-1399      GDCROSHI $ 1400-1404     GDUNDRHI $ 1405       
   STA1_1 $ 1406-1416       STA1_2 $ 1417-1426       STA1_3 $ 1427-1435    
   STA1_4 $ 1436-1444       STA1_5 $ 1445-1453       STA1_6 $ 1454-1462    
   STA1_7 $ 1463-1471       STA1_8 $ 1472-1480       STA1_9 $ 1481-1489    
   STA1_10 $ 1490-1498      STA1_11 $ 1499-1504      STA1_12 $ 1505-1513   
   STA1_13 $ 1514-1519      STA1_14 $ 1520-1525      STA1_15 $ 1526-1531   
   STA1_16 $ 1532-1537      STA1_17 $ 1538-1543      STA1_18 $ 1544-1549   
   STA1_19 $ 1550-1555      STA1_20 $ 1556-1561      STA1_21 $ 1562-1567   
   STA1_22 $ 1568-1573      STA1_23 $ 1574-1579      STA1_24 $ 1580-1585   
   STA1_25 $ 1586-1591      STA1_26 $ 1592-1597      STA1_27 $ 1598-1603   
   STA1_28 $ 1604-1609      STA1_29 $ 1610-1615      STA1_30 $ 1616-1621   
   STA1_31 $ 1622-1627      STA1_32 $ 1628-1633      STA1_33 $ 1634-1639   
   STA1_34 $ 1640-1645      STA1_35 $ 1646-1651      STA1_36 $ 1652-1657   
   STA1_37 $ 1658-1663      STA1_38 $ 1664-1669      STA1_39 $ 1670-1675   
   STA1_40 $ 1676-1681      STA1_41 $ 1682-1687      STA2_1 $ 1688-1700    
   STA2_2 $ 1701-1713       STA2_3 $ 1714-1722       STA2_4 $ 1723-1731    
   STA2_5 $ 1732-1740       STA2_6 $ 1741-1749       STA2_7 $ 1750-1758    
   STA2_8 $ 1759-1761       STA2_9 $ 1762-1764       STA2_10 $ 1765-1767   
   STA2_11 $ 1768-1770      STA2_12 $ 1771-1778      STA2_13 $ 1779-1784   
   STA2_14 $ 1785-1787      STA2_15 $ 1788-1790      STA2_16 $ 1791-1793   
   STA2_17 $ 1794-1796      STA2_18 $ 1797-1799      STA2_19 $ 1800-1802   
   STA2_20 $ 1803-1805      STA2_21 $ 1806-1808      STA2_22 $ 1809-1811   
   STA2_23 $ 1812-1814      STA2_24 $ 1815-1817      STA2_25 $ 1818-1820   
   STA2_26 $ 1821-1823      STA2_27 $ 1824-1826      STA2_28 $ 1827-1829   
   STA2_29 $ 1830-1832      STA2_30 $ 1833-1835      STA2_31 $ 1836-1838   
   STA2_32 $ 1839-1841      STA2_33 $ 1842-1844      STA2_34 $ 1845-1847   
   STA2_35 $ 1848-1850      STA2_36 $ 1851-1853      STA2_37 $ 1854-1856   
   STA2_38 $ 1857           STA2_39 $ 1858           STA2_40 $ 1859        
   STA2_41 $ 1860           STA3_1 $ 1861-1869       STA3_2 $ 1870-1878    
   STA3_3 $ 1879-1885       STA3_4 $ 1886-1888       STA3_5 $ 1889         
   STA3_6 $ 1890            STA3_7 $ 1891            STA3_8 $ 1892         
   STA3_9 $ 1893            STA3_10 $ 1894           STA3_11 $ 1895        
   STA3_12 $ 1896           STA3_13 $ 1897           STA3_14 $ 1898        
   STA3_15 $ 1899           STA3_16 $ 1900           STA3_17 $ 1901        
   STA3_18 $ 1902           STA3_19 $ 1903           STA3_20 $ 1904        
   STA3_21 $ 1905           STA3_22 $ 1906           STA3_23 $ 1907        
   STA3_24 $ 1908           STA3_25 $ 1909           STA3_26 $ 1910        
   STA3_27 $ 1911           STA3_28 $ 1912           STA3_29 $ 1913        
   STA3_30 $ 1914           STA3_31 $ 1915           STA3_32 $ 1916        
   STA3_33 $ 1917           STA3_34 $ 1918           STA3_35 $ 1919        
   STA3_36 $ 1920           STA3_37 $ 1921           STA3_38 $ 1922        
   STA3_39 $ 1923           STA3_40 $ 1924           STA3_41 $ 1925        
   NWSTAT1 $ 1926-1936      NWSTAT2 $ 1937-1949      NWSTAT3 $ 1950-1962   
   NWSTAT4 $ 1963-1971      NWSTAT5 $ 1972-1979      NWSTAT6 $ 1980-1986   
   SMAX1  1987-1995         SMAX2  1996-2002         SMAX3  2003-2008      
   SMAX4  2009-2014         SMAX5  2015-2020         SMAX6  2021-2026      
   SMAX7  2027-2032         SMAX8  2033-2038         SMAX9  2039-2044      
   SMAX10  2045-2050        SMAX11  2051-2056        SMAX12  2057-2062     
   SMAX13  2063-2068        SMAX14  2069-2074        SMAX15  2075-2080     
   SMAX16  2081-2086        SMAX17  2087-2092        SMAX18  2093-2098     
   SMAX19  2099-2104        SMAX20  2105-2110        SMAX21  2111-2116     
   SMAX22  2117-2122        SMAX23  2123-2128        SMAX24  2129-2134     
   SMAX25  2135-2140        SMAX26  2141-2146        SMAX27  2147-2152     
   SMAX28  2153-2158        SMAX29  2159-2164        SMAX30  2165-2170     
   SMAX31  2171-2176        SMAX32  2177-2182        SMAX33  2183-2188     
   SMAX34  2189-2194        SMAX35  2195-2200        SMAX36  2201-2206     
   SMAX37  2207-2212        SMAX38  2213-2218        SMAX39  2219-2224     
   SMAX40  2225-2230        SMAX41  2231-2236        SMIN1  2237-2240      
   SMIN2  2241              SMIN3  2242              SMIN4  2243           
   SMIN5  2244              SMIN6  2245              SMIN7  2246           
   SMIN8  2247              SMIN9  2248              SMIN10  2249          
   SMIN11  2250             SMIN12  2251             SMIN13  2252          
   SMIN14  2253             SMIN15  2254             SMIN16  2255          
   SMIN17  2256             SMIN18  2257             SMIN19  2258          
   SMIN20  2259             SMIN21  2260             SMIN22  2261          
   SMIN23  2262             SMIN24  2263             SMIN25  2264          
   SMIN26  2265             SMIN27  2266             SMIN28  2267          
   SMIN29  2268             SMIN30  2269             SMIN31  2270          
   SMIN32  2271             SMIN33  2272             SMIN34  2273          
   SMIN35  2274             SMIN36  2275             SMIN37  2276          
   SMIN38  2277             SMIN39  2278             SMIN40  2279          
   SMIN41  2280             RETEXT1 $ 2281           RETEXT2 $ 2282        
   RETEXT3 $ 2283           RETEXT4 $ 2284           RETEXT5 $ 2285        
   RETEXT6 $ 2286           RETEXT7 $ 2287           RETEXT8 $ 2288        
   RETEXT9 $ 2289           RETEXT10 $ 2290          RESTCAT  2291         
   FINECAT  2292            SUSFNCAT  2293           LCAT1  2294           
   LCAT2  2295              LCATHI  2296             LCATS1  2297          
   LCATS2  2298             LCATSHI  2299            LCATR1  2300          
   LCATR2  2301             LCATRHI  2302            LCATC1  2303          
   LCATC2  2304             LCATCHI  2305            LCATU1  2306          
   LCATU2  2307             LCATUHI  2308          ;                       

LENGTH
   DISGORGE 6               ACCEPT 3                 BOOKER2 3             
   BOOKER3 3                BOOKERCD 3               BUSCLAS 4             
   CANTPAY 3                CCULPSCO 3               CH2APP 3              
   CH8FINGD 3               CMSRVORD 3               COFI 3                
   COMPLY 3                 COMPLYPR 3               CRIMPURP 3            
   DETBFINE 3               DISPOSIT 3               EMPLOYNM 3            
   FCULPSCO 3               FRAUDTYP 3               FINSTDS 3             
   HISTORY 3                HSMISCND 3               INCORLOC 3            
   INCORPYR 4               INDICT 3                 INPLEA1 3             
   INPLEA2 3                INPLEA3 3                INPLEA4 3             
   INPLEA5 3                INPLEA6 3                INPLEA7 3             
   INPLEA8 3                INPLEA9 3                INPLEA10 3            
   INPLEA11 3               INPLEA12 3               INNOPL1 3             
   INNOPL2 3                INNOPL3 3                INNOPL4 3             
   INNOPL5 3                INNOPL6 3                INNOPL7 3             
   INNOPL8 3                INNOPL9 3                INNOPL10 3            
   INNOPL11 3               INNOPL12 3               JANDC 3               
   NEWCNVTN 3               NOCOMP 3                 NOCOUNTS 3            
   NOUSTAT 3                OBSTRUCT 3               OFFLVL 3              
   ORDERCE 3                ORGTYPE 3                OWNSTRCT 3            
   PLEA 3                   PRIMOFF 3                PRCIVIL 3             
   PRCRIME 3                PROBATN 3                PROBMON 3             
   PSR 3                    QUARTER 3                REAS1 4               
   REAS2 3                  REAS3 3                  REAS4 3               
   REAS5 3                  REAS6 3                  REAS7 3               
   REAS8 3                  REAS9 3                  REAS10 3              
   REASONS 3                REMEDORD 3               SELFREP 3             
   SOURCES 3                TOLERNCE 3               TYPEOTHS 3            
   VICTNOTE 3               VIOLATE 3                AMENDYR 4             
   SENTYR 4                 BASEFINE 6               COSTASSM 3            
   FINOFFST 6               FORFEITR 6               GLFINMAX 6            
   GLFINMIN 6               STATMIN 4                STATMAX 6             
   CPIDN 6                  ADJOFL1 3                ADJOFL2 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_PHI 3                ADJ_Q1 3                 ADJ_Q2 3              
   ADJ_QHI 3                ADJ_R1 3                 ADJ_R2 3              
   ADJ_RHI 3                ADJ_S1 3                 ADJ_S2 3              
   ADJ_SHI 3                BASADJ1 3                BASADJ2 3             
   BASADJHI 3               BASE1 3                  BASE2 3               
   BASEHI 3                 BASLN1 3                 BASLN2 3              
   BASLNHI 3                ADJOFR1 3                ADJOFR2 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_B2 3             
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_E2 3             
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_H2 3             
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_K2 3             
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_N2 3             
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_PHI 3               ADJR_Q1 3                ADJR_Q2 3             
   ADJR_QHI 3               ADJR_R1 3                ADJR_R2 3             
   ADJR_RHI 3               ADJR_S1 3                ADJR_S2 3             
   ADJR_SHI 3               BASADR1 3                BASADR2 3             
   BASADRHI 3               BASER1 3                 BASER2 3              
   BASERHI 3                BASLNR1 3                BASLNR2 3             
   BASLNRHI 3               ADJOFS1 3                ADJOFS2 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_B2 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_CHI 3               ADJS_D1 3                ADJS_D2 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_E2 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_FHI 3               ADJS_G1 3                ADJS_G2 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_H2 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_IHI 3               ADJS_J1 3                ADJS_J2 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_K2 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_LHI 3               ADJS_M1 3                ADJS_M2 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_N2 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_OHI 3               ADJS_P1 3                ADJS_P2 3             
   ADJS_PHI 3               ADJS_Q1 3                ADJS_Q2 3             
   ADJS_QHI 3               ADJS_R1 3                ADJS_R2 3             
   ADJS_RHI 3               ADJS_S1 3                ADJS_S2 3             
   ADJS_SHI 3               BASADS1 3                BASADS2 3             
   BASADSHI 3               BASES1 3                 BASES2 3              
   BASESHI 3                BASLNS1 3                BASLNS2 3             
   BASLNSHI 3               ADJOFC1 3                ADJOFC2 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_BHI 3               ADJC_C1 3                ADJC_C2 3             
   ADJC_CHI 3               ADJC_D1 3                ADJC_D2 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_EHI 3               ADJC_F1 3                ADJC_F2 3             
   ADJC_FHI 3               ADJC_G1 3                ADJC_G2 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_HHI 3               ADJC_I1 3                ADJC_I2 3             
   ADJC_IHI 3               ADJC_J1 3                ADJC_J2 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_KHI 3               ADJC_L1 3                ADJC_L2 3             
   ADJC_LHI 3               ADJC_M1 3                ADJC_M2 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_NHI 3               ADJC_O1 3                ADJC_O2 3             
   ADJC_OHI 3               ADJC_P1 3                ADJC_P2 3             
   ADJC_PHI 3               ADJC_Q1 3                ADJC_Q2 3             
   ADJC_QHI 3               ADJC_R1 3                ADJC_R2 3             
   ADJC_RHI 3               ADJC_S1 3                ADJC_S2 3             
   ADJC_SHI 3               BASADC1 3                BASADC2 3             
   BASADCHI 3               BASEC1 3                 BASEC2 3              
   BASECHI 3                BASLNC1 3                BASLNC2 3             
   BASLNCHI 3               ADJOFU1 3                ADJOFU2 3             
   ADJOFUHI 3               ADJU_B1 3                ADJU_B2 3             
   ADJU_BHI 3               ADJU_C1 3                ADJU_C2 3             
   ADJU_CHI 3               ADJU_D1 3                ADJU_D2 3             
   ADJU_DHI 3               ADJU_E1 3                ADJU_E2 3             
   ADJU_EHI 3               ADJU_F1 3                ADJU_F2 3             
   ADJU_FHI 3               ADJU_G1 3                ADJU_G2 3             
   ADJU_GHI 3               ADJU_H1 3                ADJU_H2 3             
   ADJU_HHI 3               ADJU_I1 3                ADJU_I2 3             
   ADJU_IHI 3               ADJU_J1 3                ADJU_J2 3             
   ADJU_JHI 3               ADJU_K1 3                ADJU_K2 3             
   ADJU_KHI 3               ADJU_L1 3                ADJU_L2 3             
   ADJU_LHI 3               ADJU_M1 3                ADJU_M2 3             
   ADJU_MHI 3               ADJU_N1 3                ADJU_N2 3             
   ADJU_NHI 3               ADJU_O1 3                ADJU_O2 3             
   ADJU_OHI 3               ADJU_P1 3                ADJU_P2 3             
   ADJU_PHI 3               ADJU_Q1 3                ADJU_Q2 3             
   ADJU_QHI 3               ADJU_R1 3                ADJU_R2 3             
   ADJU_RHI 3               ADJU_S1 3                ADJU_S2 3             
   ADJU_SHI 3               BASADU1 3                BASADU2 3             
   BASADUHI 3               BASEU1 3                 BASEU2 3              
   BASEUHI 3                BASLNU1 3                BASLNU2 3             
   BASLNUHI 3               SMAX1 6                  SMAX2 6               
   SMAX3 6                  SMAX4 6                  SMAX5 6               
   SMAX6 6                  SMAX7 6                  SMAX8 6               
   SMAX9 6                  SMAX10 6                 SMAX11 6              
   SMAX12 6                 SMAX13 6                 SMAX14 6              
   SMAX15 6                 SMAX16 6                 SMAX17 6              
   SMAX18 6                 SMAX19 6                 SMAX20 6              
   SMAX21 6                 SMAX22 6                 SMAX23 6              
   SMAX24 6                 SMAX25 6                 SMAX26 6              
   SMAX27 6                 SMAX28 6                 SMAX29 6              
   SMAX30 6                 SMAX31 6                 SMAX32 6              
   SMAX33 6                 SMAX34 6                 SMAX35 6              
   SMAX36 6                 SMAX37 6                 SMAX38 6              
   SMAX39 6                 SMAX40 6                 SMAX41 6              
   SMIN1 4                  SMIN2 3                  SMIN3 3               
   SMIN4 3                  SMIN5 3                  SMIN6 3               
   SMIN7 3                  SMIN8 3                  SMIN9 3               
   SMIN10 3                 SMIN11 3                 SMIN12 3              
   SMIN13 3                 SMIN14 3                 SMIN15 3              
   SMIN16 3                 SMIN17 3                 SMIN18 3              
   SMIN19 3                 SMIN20 3                 SMIN21 3              
   SMIN22 3                 SMIN23 3                 SMIN24 3              
   SMIN25 3                 SMIN26 3                 SMIN27 3              
   SMIN28 3                 SMIN29 3                 SMIN30 3              
   SMIN31 3                 SMIN32 3                 SMIN33 3              
   SMIN34 3                 SMIN35 3                 SMIN36 3              
   SMIN37 3                 SMIN38 3                 SMIN39 3              
   SMIN40 3                 SMIN41 3                 RESTCAT 3             
   FINECAT 3                SUSFNCAT 3               LCAT1 3               
   LCAT2 3                  LCATHI 3                 LCATS1 3              
   LCATS2 3                 LCATSHI 3                LCATR1 3              
   LCATR2 3                 LCATRHI 3                LCATC1 3              
   LCATC2 3                 LCATCHI 3                LCATU1 3              
   LCATU2 3                 LCATUHI 3 ;

         

RUN ;
